import Vue from "vue";
import Router from "vue-router";

Vue.use(Router);

/* Layout */
import Layout from "@/layout";

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */
// 1、管理员；2、省级总帐号；3、升级；4、市级；5、区级（普通账号）；99、企业(楼宇）
/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: "/login",
    component: () => import("@/views/login/index"),
    hidden: true,
  },

  {
    path: "/404",
    component: () => import("@/views/404"),
    hidden: true,
  },
  {
    path: "/user",
    component: Layout,
    children: [
      {
        path: "index",
        name: "user_manage",
        component: () => import("@/views/user_manage/index"),
        meta: { title: "账号管理", role: [0], icon: "el-icon-menu" },
      },
    ],
  },
  {
    path: "/filePath",
    component: Layout,
    children: [
      {
        path: "filePath",
        name: "filePath",
        component: () => import("@/views/filePath/index"),
        meta: { title: "文件路径管理", role: [0,1], icon: "el-icon-paperclip" },
      },
    ],
  },
  {
    path: "/",
    component: Layout,
    redirect: "/index",
    children: [
      {
        path: "index",
        name: "machine_list",
        component: () => import("@/views/machine_list/index"),
        meta: {
          title: "设备列表",
          role: [0,1],
          icon: "el-icon-cpu",
        },
      },
    ],
  },
  {
    path: "/install_management",
    component: Layout,
    meta: { title: '安装升级管理', icon: 'el-icon-folder-checked' },
    children: [
      {
        path: "installation_package",
        name: "installation_package",
        component: () =>
          import("@/views/install_management/installation_package"),
        meta: { title: "安装包列表",icon: "el-icon-folder-opened", },
      },
      {
        path: "installation_task",
        name: "installation_task",
        component: () => import("@/views/install_management/installation_task"),
        meta: { title: "安装任务列表", icon: "el-icon-tickets", },
      },
    ],
  },
  {
    path: "/logsList",
    component: Layout,
    redirect: "/logsList/index",
    name: "auth",
    meta: { title: "日志列表", icon: "el-icon-monitor" },
    children: [
      {
        path: "index",
        name: "index",
        component: () => import("@/views/logsList/index"),
        meta: { title: "日志列表" },
      },
    ],
  },
  // 404 page must be placed at the end !!!
  { path: "*", redirect: "/404", hidden: true },
];

const createRouter = () =>
  new Router({
    // mode: 'history', // require service support
    scrollBehavior: () => ({ y: 0 }),
    routes: constantRoutes,
  });

const router = createRouter();

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter();
  router.matcher = newRouter.matcher; // reset router
}

export default router;
