import { login, getInfo } from "@/api/user";
import { getToken, setToken, removeToken } from "@/utils/auth";
import { resetRouter } from "@/router";
import { isLogOut, notLogOut } from "@/utils/waitLogOut";

const getDefaultState = () => {
  return {
    token: getToken(),
    username: "",
    nickname: "",
    role: "",
    adminId: "",
    company: "",
    WebSocketData: null,
  };
};

const state = getDefaultState();

const mutations = {
  RESET_STATE: (state) => {
    Object.assign(state, getDefaultState());
  },
  SET_TOKEN: (state, token) => {
    state.token = token;
  },
  SET_USERNAME: (state, username) => {
    state.username = username;
  },
  SET_NICKNAME: (state, nickname) => {
    state.nickname = nickname;
  },
  SET_ROLE: (state, role) => {
    state.role = role;
  },
  SET_ADMINID: (state, adminId) => {
    state.adminId = adminId;
  },
  SET_COMPANY: (state, company) => {
    state.company = company;
  },
  SET_COMPANY: (state, company) => {
    state.company = company;
  },
  SET_WEBSOCKETDATA: (state, WebSocketData) => {
    state.WebSocketData = WebSocketData;
  },
};

const actions = {
  // user login
  login({ commit }, userInfo) {
    const { username, password } = userInfo;
    return new Promise((resolve, reject) => {
      login({ username: username.trim(), password: password })
        .then((response) => {
          // 标记登录,开始检测长时间未操作情况
          notLogOut();

          const { data } = response;
          commit("SET_TOKEN", data.token);
          commit("SET_ROLE", data.type);
          commit("SET_USERNAME", data.username);
          commit("SET_NICKNAME", data.nickname);
          commit("SET_ADMINID", data.accountId);
          commit("SET_COMPANY", data.company);
          setToken(data.token);
          resolve();
        })
        .catch((error) => {
          reject(error);
        });
    });
  },

  // get user info
  getInfo({ commit, state }) {
    return new Promise((resolve, reject) => {
      getInfo(state.token)
        .then((response) => {
          const { data } = response;
          if (!data) {
            return reject("Verification failed, please Login again.");
          }
          commit("SET_ROLE", data.type);
          commit("SET_USERNAME", data.username);
          commit("SET_NICKNAME", data.nickname);
          commit("SET_ADMINID", data.id);
          commit("SET_COMPANY", data.company);
          resolve(data);
        })
        .catch((error) => {
          reject(error);
        });
    });
  },
  // get user info
  getWebSocket({ commit,state }, WebSocketData) {
    return new Promise((resolve, reject) => {
      commit("SET_WEBSOCKETDATA", WebSocketData);
      resolve(state);
    });
  },
  // user logout
  logout({ commit, state }) {
    return new Promise((resolve, reject) => {
      // 标记已经退出,不用再检测长时间未操作情况
      isLogOut();

      // logout(state.token).then(() => {
      removeToken(); // must remove  token  first
      resetRouter();
      commit("RESET_STATE");
      resolve();
      // }).catch(error => {
      //   reject(error)
      // })
    });
  },

  // remove token
  resetToken({ commit }) {
    return new Promise((resolve) => {
      removeToken(); // must remove  token  first
      commit("RESET_STATE");
      resolve();
    });
  },
};

export default {
  namespaced: true,
  state,
  mutations,
  actions,
};
